@@ -15,7 +15,6 @@
 /* global EnigEditKeyTrust: false, EnigEditKeyExpiry: false, EnigSignKey: false, EnigRevokeKey: false, EnigCreateRevokeCert: false */
 /* global EnigLongAlert: false, EnigChangeKeyPwd: false, EnigDownloadKeys: false, EnigSetPref: false, EnigGetTrustCode: false */
 /* global ENIG_KEY_DISABLED: false, ENIG_KEY_NOT_VALID: false, ENIG_IOSERVICE_CONTRACTID: false, ENIG_LOCAL_FILE_CONTRACTID: false */
-/* global ENIG_CLIPBOARD_CONTRACTID: false, ENIG_TRANSFERABLE_CONTRACTID: false, ENIG_CLIPBOARD_HELPER_CONTRACTID: false */
 
 // imported packages
 /* global EnigmailLog: false, EnigmailEvents: false, EnigmailKeyRing: false, EnigmailWindows: false, EnigmailKeyEditor: false */
@@ -28,7 +27,8 @@ const Cc = Components.classes;
 const Ci = Components.interfaces;
 const Cu = Components.utils;
 
-Components.utils.import("resource://enigmail/streams.jsm"); /*global EnigmailStreams: false */
+Cu.import("resource://enigmail/streams.jsm"); /*global EnigmailStreams: false */
+Cu.import("resource://enigmail/clipboard.jsm"); /*global EnigmailClipboard: false */
 
 
 const INPUT = 0;
@@ -62,6 +62,8 @@ function enigmailKeyManagerLoad() {
   gShowUntrustedKeys = document.getElementById("showUntrustedKeys");
   gShowOthersKeys = document.getElementById("showOthersKeys");
 
+  window.addEventListener("reload-keycache", enigmailRefreshKeys);
+
   if (EnigGetPref("keyManShowAllKeys")) {
     gShowAllKeysElement.setAttribute("checked", "true");
   }
@@ -465,7 +467,9 @@ function enigmailSelectAllKeys() {
 function enigmailKeyDetails() {
   var keyList = enigmailGetSelectedKeys();
   if (keyList.length > 0) {
-    EnigmailWindows.openKeyDetails(window, gKeyList[keyList[0]].keyId, false);
+    if (EnigmailWindows.openKeyDetails(window, gKeyList[keyList[0]].keyId, false)) {
+      enigmailRefreshKeys();
+    }
   }
 }
 
@@ -918,6 +922,11 @@ function enigmailImportKeysFromFile() {
   var errorMsgObj = {};
   // preview
   var preview = EnigmailKey.getKeyListFromKeyFile(inFile, errorMsgObj);
+
+  if (errorMsgObj.value && errorMsgObj.value.length > 0) {
+    EnigmailDialog.alert(window, errorMsgObj.value);
+    return;
+  }
   var exitStatus = -1;
 
   if (preview.length > 0) {
@@ -950,6 +959,11 @@ function enigmailImportKeysFromFile() {
       enigmailRefreshKeys();
     }
   }
+  else {
+    if (EnigmailKeyRing.getCacheEmpty()) {
+      enigmailRefreshKeys();
+    }
+  }
 }
 
 
@@ -976,22 +990,7 @@ function enigmailChangePwd() {
 
 
 function enigGetClipboard() {
-  EnigmailLog.DEBUG("enigmailKeyManager.js: enigGetClipboard:\n");
-  var cBoardContent = "";
-  var clipBoard = Cc[ENIG_CLIPBOARD_CONTRACTID].getService(Ci.nsIClipboard);
-  try {
-    var transferable = Cc[ENIG_TRANSFERABLE_CONTRACTID].createInstance(Ci.nsITransferable);
-    transferable.addDataFlavor("text/unicode");
-    clipBoard.getData(transferable, clipBoard.kGlobalClipboard);
-    var flavour = {};
-    var data = {};
-    var length = {};
-    transferable.getAnyTransferData(flavour, data, length);
-    cBoardContent = data.value.QueryInterface(Ci.nsISupportsString).data;
-    EnigmailLog.DEBUG("enigmailKeyManager.js: enigGetClipboard: got data\n");
-  }
-  catch (ex) {}
-  return cBoardContent;
+  return EnigmailClipboard.getClipboardContent(window, Ci.nsIClipboard.kGlobalClipboard);
 }
 
 function enigmailImportFromClipbrd() {
@@ -1052,20 +1051,13 @@ function enigmailCopyToClipbrd() {
     EnigAlert(EnigGetString("copyToClipbrdFailed") + "\n\n" + errorMsgObj.value);
     return;
   }
-  var clipBoard = Cc[ENIG_CLIPBOARD_CONTRACTID].getService(Ci.nsIClipboard);
-  try {
-    let clipBoardHlp = Cc[ENIG_CLIPBOARD_HELPER_CONTRACTID].getService(Ci.nsIClipboardHelper);
-    clipBoardHlp.copyStringToClipboard(keyData, clipBoard.kGlobalClipboard);
-    if (clipBoard.supportsSelectionClipboard()) {
-      clipBoardHlp.copyStringToClipboard(keyData, clipBoard.kSelectionClipboard);
-    }
-    EnigmailLog.DEBUG("enigmailKeyManager.js: enigmailImportFromClipbrd: got data from clipboard");
+  if (EnigmailClipboard.setClipboardContent(keyData)) {
+    EnigmailLog.DEBUG("enigmailKeyManager.js: enigmailImportFromClipbrd: set clipboard data");
     EnigAlert(EnigGetString("copyToClipbrdOK"));
   }
-  catch (ex) {
+  else {
     EnigAlert(EnigGetString("copyToClipbrdFailed"));
   }
-
 }
 
 function enigmailSearchKey() {
